@@ -8,6 +8,8 @@
 
 #include <config-krfb.h>
 #include <QCursor>
+#include <QGuiApplication>
+#include <QScreen>
 
 
 FrameBuffer::FrameBuffer(QObject *parent)
@@ -72,5 +74,14 @@ void FrameBuffer::stopMonitor()
 
 QPoint FrameBuffer::cursorPosition()
 {
-    return QCursor::pos();
+    QPoint cursorPos = QCursor::pos();
+    QScreen *primaryScreen = QGuiApplication::primaryScreen();
+    if (primaryScreen) {
+        qreal scaleFactor = primaryScreen->devicePixelRatio();
+        cursorPos.setX(qRound(cursorPos.x() * scaleFactor));
+        cursorPos.setY(qRound(cursorPos.y() * scaleFactor));
+    } else {
+        qWarning() << "cursorPosition: ERROR: Failed to get application's primary screen info!";
+    }
+    return cursorPos;
 }
